==> jc-1.4.0.tar.gz: javax/imageio/ImageIO__24ImageWriterIterator.h <==
// final class javax.imageio.ImageIO$ImageWriterIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cf900506eac288de javax_imageio_ImageIO__24ImageWriterIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageIO__24ImageWriterIterator_H_
#define _JC_javax_imageio_ImageIO__24ImageWriterIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_refs	_jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_refs;
typedef struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_nonrefs	_jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$refs	_jc_javax_imageio_ImageIO__24ImageWriterIterator$refs;
typedef struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$nonrefs	_jc_javax_imageio_ImageIO__24ImageWriterIterator$nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object	_jc_javax_imageio_ImageIO__24ImageWriterIterator$object;

typedef const struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vmethods	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vmethods;
typedef const struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vtable	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vtable;
typedef const struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vtype	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vtype;

// Constructors
extern void _jc_javax_imageio_ImageIO__24ImageWriterIterator$method$_init$883e05981aacbe90(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *, struct _jc_object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_javax_imageio_ImageIO__24ImageWriterIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_imageio_ImageIO__24ImageWriterIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *);
extern void _jc_javax_imageio_ImageIO__24ImageWriterIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageIO__24ImageWriterIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_javax_imageio_ImageIO__24ImageWriterIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_javax_imageio_ImageIO__24ImageWriterIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *);
};

// Vtable
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vmethods	javax_imageio_ImageIO__24ImageWriterIterator;
};

// Vtype
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_refs {
	struct _jc_object	*it;
	struct _jc_java_lang_Object$object	*writerExtension;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$refs {
    _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_refs	javax_imageio_ImageIO__24ImageWriterIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_nonrefs	javax_imageio_ImageIO__24ImageWriterIterator;
};

// Object instance structure
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object {
	_jc_javax_imageio_ImageIO__24ImageWriterIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vtype	*vtype;
	_jc_javax_imageio_ImageIO__24ImageWriterIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageIO__24ImageWriterIterator$vtype _jc_javax_imageio_ImageIO__24ImageWriterIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageIO__24ImageWriterIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageIO__24ImageWriterIterator$class_object;

#endif	/* _JC_javax_imageio_ImageIO__24ImageWriterIterator_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/ImageIO__24ImageWriterIterator.h <==
// final class javax.imageio.ImageIO$ImageWriterIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cf900506eac288de javax_imageio_ImageIO__24ImageWriterIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageIO__24ImageWriterIterator_H_
#define _JC_javax_imageio_ImageIO__24ImageWriterIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_refs	_jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_refs;
typedef struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_nonrefs	_jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$refs	_jc_javax_imageio_ImageIO__24ImageWriterIterator$refs;
typedef struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$nonrefs	_jc_javax_imageio_ImageIO__24ImageWriterIterator$nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object	_jc_javax_imageio_ImageIO__24ImageWriterIterator$object;

typedef const struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vmethods	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vmethods;
typedef const struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vtable	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vtable;
typedef const struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vtype	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vtype;

// Constructors
extern void _jc_javax_imageio_ImageIO__24ImageWriterIterator$method$_init$883e05981aacbe90(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *, struct _jc_object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_imageio_ImageIO__24ImageWriterIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_imageio_ImageIO__24ImageWriterIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_ImageIO__24ImageWriterIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageIO__24ImageWriterIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_javax_imageio_ImageIO__24ImageWriterIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_javax_imageio_ImageIO__24ImageWriterIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vmethods	javax_imageio_ImageIO__24ImageWriterIterator;
};

// Vtype
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_refs {
	struct _jc_object	*it;
	struct _jc_java_lang_Object$object	*writerExtension;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$refs {
    _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_refs	javax_imageio_ImageIO__24ImageWriterIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageIO__24ImageWriterIterator$sub_nonrefs	javax_imageio_ImageIO__24ImageWriterIterator;
};

// Object instance structure
struct _jc_javax_imageio_ImageIO__24ImageWriterIterator$object {
	_jc_javax_imageio_ImageIO__24ImageWriterIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageIO__24ImageWriterIterator$vtype	*vtype;
	_jc_javax_imageio_ImageIO__24ImageWriterIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageIO__24ImageWriterIterator$vtype _jc_javax_imageio_ImageIO__24ImageWriterIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageIO__24ImageWriterIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageIO__24ImageWriterIterator$class_object;

#endif	/* _JC_javax_imageio_ImageIO__24ImageWriterIterator_H_ */
